/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.wso2.registry.servlet.actions;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Each registry action should be implemented as an ActionProcessor (e.g. add resource,
 * tag resource, get ratings for a resource). Then those ActionProcessors should identify its
 * corresponding action and invoke the mapping method in the registry. ActionProcessor is
 * responsible for extratcing necessary parameters for the registry method invocation
 * and building the HttpServletResponse after completing the invocation. Any other considerations
 * related to the processing of actions should NOT be implemented in the ActionProcessor and
 * such processing should be done by various handlers configured for the registry.
 */
public interface ActionProcessor {

    public boolean process(String path,
                           HttpServletRequest request,
                           HttpServletResponse response);
}
